@@ -1,5 +1,7 @@
 DEV_BASE_URL = 'https://newapidev.bni.co.id:8066';
+UAT_BASE_URL = 'https://newapidev.bni.co.id:8065';
 SANDBOX_BASE_URL = 'https://sandbox.bni.co.id';
+SANDBOX_DEV_BASE_URL = 'https://sb-dev.harismawan.com';
 PRODUCTION_BASE_URL = 'https://api.bni.co.id';
 # DEV_OGP_URL = 'https://sandbox.harismawan.com'
 # DEV_SNAP_BI = 'https://dev.harismawan.com'
@@ -8,7 +10,7 @@ APP_NAME = 'Test APP'
 APP_NAME_TEST = 'Test Wawat'
 
 CLIENT_ID_BASE64 = 'IDBNIVGVzdCBBUFA='
-API_SECRET = 'test-secret'
+API_SECRET = 'test-secret'  
 API_KEY = '12345'
 CLIENT_ID = 'test12345'
 CLIENT_SECRET = 'test54321'
